@@ -1,8 +1,8 @@
-# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple.pm,v 1.13 2007/11/22 18:21:56 matisse Exp $
-# $Revision: 1.13 $
+# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple.pm,v 1.15 2007/12/30 21:37:31 matisse Exp $
+# $Revision: 1.15 $
 # $Author: matisse $
 # $Source: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple.pm,v $
-# $Date: 2007/11/22 18:21:56 $
+# $Date: 2007/12/30 21:37:31 $
 ###############################################################################
 
 package Perl::Metrics::Simple;
@@ -14,12 +14,13 @@ use Data::Dumper;
 use English qw(-no_match_vars);
 use File::Basename qw(fileparse);
 use File::Find qw(find);
+use IO::File;
 use PPI;
 use Perl::Metrics::Simple::Analysis;
 use Perl::Metrics::Simple::Analysis::File;
 use Readonly;
 
-our $VERSION = '0.034';
+our $VERSION = '0.1';
 
 Readonly::Scalar our $PERL_FILE_SUFFIXES => qr{ \. (:? pl | pm | t ) }xmi;
 Readonly::Scalar our $SKIP_LIST_REGEX    => qr{ \.svn | _darcs | CVS }xmi;
@@ -46,8 +47,7 @@ sub analyze_files {
 }
 
 sub find_files {
-    my $self                  = shift;
-    my @directories_and_files = @_;
+    my ($self, @directories_and_files) = @_;
     foreach my $path (@directories_and_files) {
         if ( !-r $path ) {
             confess "Path '$path' is not readable!";
@@ -95,13 +95,13 @@ sub is_perl_file {
 sub _has_perl_shebang {
     my $path = shift;
 
-    open my $fh, '<', $path;
+    my $fh = IO::File->new( $path, '<' );
     if ( !-r $fh ) {
         cluck "Could not open '$path' for reading: $OS_ERROR";
         return;
     }
     my $first_line = <$fh>;
-    close $fh;
+    $fh->close();
     return if ( !$first_line );
     return $first_line =~ $PERL_SHEBANG_REGEX;
 }
@@ -133,18 +133,18 @@ Perl::Metrics::Simple - Count packages, subs, lines, etc. of many files.
 
 =head1 VERSION
 
-This is VERSION 0.031
+This is VERSION 0.1
 
 =head1 DESCRIPTION
 
-Perl::Metrics::Simple is far simpler that Perl::Metrics.
+Perl::Metrics::Simple is far simpler than Perl::Metrics.
 
 Perl::Metrics::Simple provides just enough methods to run static analysis
 of one or many Perl files and obtain a few metrics: packages, subroutines,
-lines of code, and an approximation of cyclomatic (mccabe) complexity of
+lines of code, and an approximation of cyclomatic (mccabe) complexity for
 the subroutines and the "main" portion of the code.
 
-Installs a a script called B<countperl>.
+Installs a script called B<countperl>.
 
 =head1 USAGE
 
