@@ -77,9 +77,14 @@ sub make_test_data {
         'no_packages_nor_subs' => {
             path       => "$test_directory/no_packages_nor_subs",
             lines      => 4,
-            main_stats => { lines => 4, mccabe_complexity => 1, },
-            subs       => [],
-            packages   => [],
+            main_stats => {
+                lines             => 4,
+                mccabe_complexity => 1,
+                name              => '{code not in named subroutines}',
+                path              => "$test_directory/no_packages_nor_subs",
+            },
+            subs     => [],
+            packages => [],
         },
         'package_no_subs.pl' => {
             path       => "$test_directory/package_no_subs.pl",
@@ -87,6 +92,8 @@ sub make_test_data {
             main_stats => {
                 lines             => 12,
                 mccabe_complexity => 3,
+                name              => '{code not in named subroutines}',
+                path              => "$test_directory/package_no_subs.pl",
             },
             subs => [
 
@@ -96,8 +103,13 @@ sub make_test_data {
         'subs_no_package.pl' => {
             path       => "$test_directory/subs_no_package.pl",
             lines      => 8,
-            main_stats => { lines => 5, mccabe_complexity => 2, },
-            subs       => [
+            main_stats => {
+                lines             => 5,
+                mccabe_complexity => 2,
+                name              => '{code not in named subroutines}',
+                path              => "$test_directory/subs_no_package.pl",
+            },
+            subs => [
                 {
                     name              => 'foo',
                     lines             => 1,
@@ -116,8 +128,13 @@ sub make_test_data {
         'Module.pm' => {
             path       => "$test_directory/Perl/Code/Analyze/Test/Module.pm",
             lines      => 29,
-            main_stats => { lines => 6, mccabe_complexity => 1, },
-            subs       => [
+            main_stats => {
+                lines             => 6,
+                mccabe_complexity => 1,
+                name              => '{code not in named subroutines}',
+                path => "$test_directory/Perl/Code/Analyze/Test/Module.pm",
+            },
+            subs => [
                 {
                     name              => 'new',
                     lines             => 5,
